AffinePoint

Struct AffinePoint 

pub struct AffinePoint {
    pub(crate) x: FieldElement,
    pub(crate) y: FieldElement,
}
This point representation is not a part of the API.

AffinePoint is mainly used as a convenience struct. XXX: Initially, I wanted to leave some of these in the library to help others learn. So if you are scrubbing the commit history. Hopefully they were helpful.

Represents an AffinePoint on the Twisted Edwards Curve with Equation y^2 - x^2 = 1 - (TWISTED_D) * x^2 * y^2

Fields

x: FieldElementy: FieldElement

Implementations

Source

impl AffinePoint

pub(crate) const IDENTITY: AffinePoint

Identity element

pub(crate) fn is_on_curve(&self) -> Choice

Checks if the AffinePoint is on the TwistedEdwards curve

pub(crate) fn negate(&self) -> AffinePoint

pub(crate) fn add(&self, other: &AffinePoint) -> AffinePoint

Adds an AffinePoint onto an AffinePoint

pub(crate) fn to_extensible(self) -> ExtensiblePoint

Converts an AffinePoint to an ExtensiblePoint

pub(crate) fn to_extended(self) -> ExtendedPoint

Converts an An AffinePoint to an ExtendedPoint